@@ -43,12 +43,12 @@ struct option longopts[] = {
 };
 
 static char *progname;
-int flagh = 0, flagv = 0, flagr = 0, flagb = 0, flago = 0, flagc = 0, flagp =
-  0;
+int flagh = 0, flagv = 0, flagr = 0, flagb = 0, flago = 0, flagc = 0, flagp = 0;
 int flagd = 0, flagl = 0, flage = 0, flags = 0, flagi = 0, flagx = 0, lose = 0;
 int depth = 9;                     // initial depth for the min-max algorithm
 int level = 0;                    // level of game
 int neh = 4;                      // max number of eaten holes
+int computer = 1, human = 0;
 double tmax[3] = {5, 20, 100};
 
 int
@@ -57,14 +57,13 @@ main (int argc, char *argv[])
   int optc;
   void print_board (int *, int *, int, char *);
   void exit_game (char *);
-  int best_move (int *, int *, int, char *);
-  int ask_move (int*, int, int, char *);
+  int best_move (int *, int *, char *);
+  int ask_move (int*, int, char *);
   int distribute (int *, int *, int, char *);
   int hole[12] = { 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4 };
   int score[2] = { 0, 0 };
   char label[4] = "RUN";
   int i, j, del[12], val[12], move = -1;
-  int comput = 1, player = 0;
   char r[64];
 
   
@@ -105,13 +104,13 @@ main (int argc, char *argv[])
 	break;
       case 'c':
 	flagc = 1;
-	if (sscanf (optarg, "%d", &comput) != 1 || comput < 1 || comput > 2)
+	if (sscanf (optarg, "%d", &computer) != 1 || computer < 1 || computer > 2)
 	  {
 	    fprintf (stderr, "Bad argument for -c option\n");
 	    exit (1);
 	  }
-	comput--;
-	player = 1 - comput;
+	computer--;
+	human = 1 - computer;
 	break;
       case 'p':
 	flagp = 1;
@@ -121,8 +120,8 @@ main (int argc, char *argv[])
 	    exit (1);
 	  }
 	move--;
-	player = who_play (move);
-	comput = who_wait (move);
+	human    = who_play (move);
+	computer = who_wait (move);
 	strcpy(label,"BEG");
 	break;
       case 'd':
@@ -290,7 +289,7 @@ The winner is the player who has eaten the most stones.\n");
 
   if (flagp)
     {
-      move = ask_move (hole, player, move, label);
+      move = ask_move (hole, move, label);
       if (valid (hole, move))
 	distribute (hole, score, move, label);
       else
@@ -302,13 +301,13 @@ The winner is the player who has eaten the most stones.\n");
 
   do
     {
-      move = best_move (hole, score, comput, label);
+      move = best_move (hole, score, label);
       distribute (hole, score, move, label);
       print_board (hole, score, move, label);
       if (!strcmp (label, "END") || flags)
 	break;
 	
-      move = ask_move (hole, player, move, label);
+      move = ask_move (hole, move, label);
       distribute (hole, score, move, label);
       print_board (hole, score, move, label);
       if (!strcmp (label, "END"))
@@ -325,7 +324,7 @@ The winner is the player who has eaten the most stones.\n");
 !ccccccccccccccccccccccccccccccccccccccccccccccccccccccc*/
 
 int
-ask_move (int hole[], int player, int move, char* label)
+ask_move (int hole[], int move, char* label)
 {
   int valid (int *, int);
   void exit_game (char *);
@@ -346,8 +345,8 @@ ask_move (int hole[], int player, int move, char* label)
           if (!strcmp (r, "quit") || !strcmp (r, "exit") || !strcmp (r, "stop") || !strcmp (r, "q"))
     	  exit_game (label);
         }
-      while (sscanf (r, "%d", &move) != 1 || move < (player * 6 + 1)
-          || move > (player * 6 + 6) || !valid (hole, move - 1));
+      while (sscanf (r, "%d", &move) != 1 || move < (human * 6 + 1)
+          || move > (human * 6 + 6) || !valid (hole, move - 1));
       move--;
     }
      
@@ -361,7 +360,7 @@ ask_move (int hole[], int player, int move, char* label)
 !ccccccccccccccccccccccccccccccccccccccccccccccccccccccc*/
 
 int
-best_move (int hole[], int score[], int comput, char *label)
+best_move (int hole[], int score[], char *label)
 {
   int valid (int *, int);
   int max (int, int);
@@ -383,30 +382,30 @@ best_move (int hole[], int score[], int comput, char *label)
       srand ((int) time (NULL));
       h = rand () % 100;
       if (h >= 00 && h < 20)
-	move = 5 + comput * 6;
+	move = 5 + computer * 6;
       if (h >= 20 && h < 40)
-	move = 4 + comput * 6;
+	move = 4 + computer * 6;
       if (h >= 40 && h < 60)
-	move = 3 + comput * 6;
+	move = 3 + computer * 6;
       if (h >= 60 && h < 80)
-	move = 2 + comput * 6;
+	move = 2 + computer * 6;
       if (h >= 80 && h < 95)
-	move = 1 + comput * 6;
+	move = 1 + computer * 6;
       if (h >= 95 && h < 100)
-	move = 0 + comput * 6;
+	move = 0 + computer * 6;
     }
   else
     {
       t1 = clock ();
 
-      for (j = comput * 6; j <= comput * 6 + 5; j++)
+      for (j = computer * 6; j <= computer * 6 + 5; j++)
 	if (valid (hole, j))
 	  {
 	    val[j] = value (hole, score, j, 0);
 	    supv = max (val[j], supv);
 	  }
 
-      for (j = comput * 6; j <= comput * 6 + 5; j++)
+      for (j = computer * 6; j <= computer * 6 + 5; j++)
 	if (valid (hole, j) && val[j] == supv)
 	  {
 	    del[j] = delay (hole, score, j);
@@ -512,9 +511,9 @@ print_board (int hole[], int score[], int move, char *label)
 
       if (!strcmp (label, "END"))
 	{
-	  if (score[0] > score[1])
+	  if (score[human] > score[computer])
 	    printf ("Tu m'as bien gagne\n");
-	  else if (score[1] > score[0])
+	  else if (score[computer] > score[human])
 	    printf ("Je t'ai bien gagne\n");
 	  else
 	    printf ("C'est meme score\n");
